@@ -188,8 +188,10 @@ def rename(filesrc, filedest, overwrite=True):
     """
     rename
     """
+    if normpath(filesrc)==normpath(filedest):
+        return True
     try:
-        if file(filedest) and overwrite:
+        if isfile(filedest)  and overwrite:
             remove(filedest)
         mkdirs(justpath(filedest))
         os.rename(filesrc, filedest)
@@ -203,6 +205,7 @@ def remove(files):
     """
     remove
     """
+    res=True
     for item in listify(files):
         try:
             if os.path.isfile(item):
@@ -211,8 +214,8 @@ def remove(files):
                 shutil.rmtree(item)
         except Exception as ex:
             print(ex)
-            pass
-
+            res=False
+    return res
 
 def mkdirs(pathname):
     """
